==> seedsui-react-5.8.44.tgz: package/lib/Signature/Combo/index.js <==
function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }
function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }
function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }
function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i]; return arr2; }
function _iterableToArrayLimit(r, l) { var t = null == r ? null : "undefined" != typeof Symbol && r[Symbol.iterator] || r["@@iterator"]; if (null != t) { var e, n, i, u, a = [], f = !0, o = !1; try { if (i = (t = t.call(r)).next, 0 === l) { if (Object(t) !== t) return; f = !1; } else for (; !(f = (e = i.call(t)).done) && (a.push(e.value), a.length !== l); f = !0); } catch (r) { o = !0, n = r; } finally { try { if (!f && null != t.return && (u = t.return(), Object(u) !== u)) return; } finally { if (o) throw n; } } return a; } }
function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }
import React, { useImperativeHandle, useRef, forwardRef, useState } from 'react';
import locale from "./../../locale";
// 测试使用
// import { Button } from 'seedsui-react'
// 内库使用
import Button from "./../../Button";
import Preview from "./Preview";
import Modal from "./../Modal";

// Combo
var Combo = function Combo(_ref, ref) {
  var value = _ref.value,
    onBeforeChange = _ref.onBeforeChange,
    onChange = _ref.onChange,
    portal = _ref.portal,
    color = _ref.color,
    backgroundColor = _ref.backgroundColor;
  var _useState = useState(false),
    _useState2 = _slicedToArray(_useState, 2),
    visible = _useState2[0],
    setVisible = _useState2[1];
  var comboRef = useRef(null);
  var modalRef = useRef(null);
  useImperativeHandle(ref, function () {
    var _comboRef$current, _modalRef$current, _modalRef$current2;
    return {
      rootDOM: comboRef !== null && comboRef !== void 0 && (_comboRef$current = comboRef.current) !== null && _comboRef$current !== void 0 && _comboRef$current.getRootDOM ? comboRef.current.getRootDOM() : comboRef.current,
      getRootDOM: function getRootDOM() {
        var _comboRef$current2;
        // div
        var rootDOM = comboRef === null || comboRef === void 0 ? void 0 : comboRef.current;
        // Input.Text
        if (comboRef !== null && comboRef !== void 0 && (_comboRef$current2 = comboRef.current) !== null && _comboRef$current2 !== void 0 && _comboRef$current2.getRootDOM) {
          rootDOM = comboRef.current.getRootDOM();
        }
        return rootDOM;
      },
      modalDOM: modalRef === null || modalRef === void 0 || (_modalRef$current = modalRef.current) === null || _modalRef$current === void 0 ? void 0 : _modalRef$current.rootDOM,
      getModalDOM: modalRef === null || modalRef === void 0 || (_modalRef$current2 = modalRef.current) === null || _modalRef$current2 === void 0 ? void 0 : _modalRef$current2.getRootDOM
    };
  });

  // 点击签名
  function handleSign() {
    setVisible(true);
  }

  // 修改签名
  function handleChange(base64) {
    setVisible(false);
    onChange === null || onChange === void 0 || onChange(base64);
  }
  // 已签显示图片
  if (value && typeof value === 'string') {
    return /*#__PURE__*/React.createElement(Preview, {
      value: value,
      onDelete: onChange ? handleChange : null
    });
  }

  // 未签显示签名
  return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(Button, {
    ref: comboRef,
    onClick: handleSign
  }, locale('签名', 'SeedsUI_signature')), /*#__PURE__*/React.createElement(Modal, {
    ref: modalRef,
    portal: portal,
    visible: visible,
    value: value,
    onBeforeChange: onBeforeChange,
    onChange: handleChange,
    onVisibleChange: function onVisibleChange(newVisible) {
      setVisible(newVisible);
    }
    // 绘画配置
    ,
    color: color,
    backgroundColor: backgroundColor
  }));
};
export default /*#__PURE__*/forwardRef(Combo);

==> seedsui-react-5.8.79.tgz: package/lib/Signature/Combo/index.js <==
var _excluded = ["value", "onBeforeChange", "onChange", "portal", "color", "backgroundColor"];
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }
function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }
function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }
function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i]; return arr2; }
function _iterableToArrayLimit(r, l) { var t = null == r ? null : "undefined" != typeof Symbol && r[Symbol.iterator] || r["@@iterator"]; if (null != t) { var e, n, i, u, a = [], f = !0, o = !1; try { if (i = (t = t.call(r)).next, 0 === l) { if (Object(t) !== t) return; f = !1; } else for (; !(f = (e = i.call(t)).done) && (a.push(e.value), a.length !== l); f = !0); } catch (r) { o = !0, n = r; } finally { try { if (!f && null != t.return && (u = t.return(), Object(u) !== u)) return; } finally { if (o) throw n; } } return a; } }
function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }
function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }
function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }
import React, { useImperativeHandle, useRef, forwardRef, useState } from 'react';
import locale from "./../../locale";
// 测试使用
// import { Button } from 'seedsui-react'
// 内库使用
import Button from "./../../Button";
import Preview from "./Preview";
import Modal from "./../Modal";

// Combo
var Combo = function Combo(_ref, ref) {
  var value = _ref.value,
    onBeforeChange = _ref.onBeforeChange,
    onChange = _ref.onChange,
    portal = _ref.portal,
    color = _ref.color,
    backgroundColor = _ref.backgroundColor,
    props = _objectWithoutProperties(_ref, _excluded);
  var _useState = useState(false),
    _useState2 = _slicedToArray(_useState, 2),
    visible = _useState2[0],
    setVisible = _useState2[1];
  var comboRef = useRef(null);
  var modalRef = useRef(null);
  useImperativeHandle(ref, function () {
    var _comboRef$current, _modalRef$current, _modalRef$current2;
    return {
      rootDOM: comboRef !== null && comboRef !== void 0 && (_comboRef$current = comboRef.current) !== null && _comboRef$current !== void 0 && _comboRef$current.getRootDOM ? comboRef.current.getRootDOM() : comboRef.current,
      getRootDOM: function getRootDOM() {
        var _comboRef$current2;
        // div
        var rootDOM = comboRef === null || comboRef === void 0 ? void 0 : comboRef.current;
        // Input.Text
        if (comboRef !== null && comboRef !== void 0 && (_comboRef$current2 = comboRef.current) !== null && _comboRef$current2 !== void 0 && _comboRef$current2.getRootDOM) {
          rootDOM = comboRef.current.getRootDOM();
        }
        return rootDOM;
      },
      modalDOM: modalRef === null || modalRef === void 0 || (_modalRef$current = modalRef.current) === null || _modalRef$current === void 0 ? void 0 : _modalRef$current.rootDOM,
      getModalDOM: modalRef === null || modalRef === void 0 || (_modalRef$current2 = modalRef.current) === null || _modalRef$current2 === void 0 ? void 0 : _modalRef$current2.getRootDOM
    };
  });

  // 点击签名
  function handleSign() {
    setVisible(true);
  }

  // 修改签名
  function handleChange(base64) {
    setVisible(false);
    onChange === null || onChange === void 0 || onChange(base64);
  }
  // 已签显示图片
  if (value && typeof value === 'string') {
    return /*#__PURE__*/React.createElement(Preview, {
      value: value,
      onDelete: onChange ? handleChange : null
    });
  }

  // 未签显示签名
  return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(Button, _extends({
    ref: comboRef
  }, props, {
    className: "signature-button".concat(props !== null && props !== void 0 && props.className ? ' ' + props.className : ''),
    onClick: handleSign
  }), /*#__PURE__*/React.createElement("i", {
    className: "signature-button-icon-add"
  }), /*#__PURE__*/React.createElement("div", {
    className: "signature-button-label"
  }, locale('签名', 'SeedsUI_signature'))), /*#__PURE__*/React.createElement(Modal, {
    ref: modalRef,
    portal: portal,
    visible: visible,
    value: value,
    onBeforeChange: onBeforeChange,
    onChange: handleChange,
    onVisibleChange: function onVisibleChange(newVisible) {
      setVisible(newVisible);
    }
    // 绘画配置
    ,
    color: color,
    backgroundColor: backgroundColor
  }));
};
export default /*#__PURE__*/forwardRef(Combo);
